;; Generated package description from setup.el  -*- no-byte-compile: t -*-
(define-package "setup" "1.4.0.0.20241123.145918" "Helpful Configuration Macro" '((emacs "26.1")) :commit "b17b6564df8383c4553bdda7021e440b555df8e7" :authors '(("Philip Kaludercic" . "philipk@posteo.net")) :maintainer '("Philip Kaludercic" . "~pkal/public-inbox@lists.sr.ht") :keywords '("lisp" "local") :url "https://git.sr.ht/~pkal/setup")
